Learn R Programming

attract (version 1.24.0)

buildKeggIncidenceMatrix: Internal function - buildings the KEGG incidence matrix requird by GSEAlm.

Description

Internal function - buildings the KEGG incidence matrix requird by GSEAlm.

Usage

buildKeggIncidenceMatrix(kegg.ids, gene.ids, annotation, database, analysis, envPos)

Arguments

kegg.ids
character vector of KEGG pathway ids.
gene.ids
character vector of gene ids.
annotation
character string that denotes which annotation package to be used, eg. illuminaHumanv1.db.
database
a character string specifiying what pathway database you would like to use.
analysis
a character string specifying what type of experiment you performed, microarray or RNAseq.
envPos
the position of the annotation package in the R search path.

Value

A matrix object with 0 and 1 entries where 1 denotes membership of a gene in a KEGG or reactome pathway, 0 denotes non-membership.

Details

This function is called internally by findAttractors.

References

Kanehisa, M. and S. Goto, KEGG: Kyoto Encyclopedia of Genes and Genomes. . Nucleic Acids Res., 2000. 28: p. 27-30.

Examples

Run this code
## Not run: 
# # this takes a long time!
# require("illuminaHumanv2.db", character.only=TRUE)
# loadNamespace("illuminaHumanv2.db")
# envPos <- match(paste("package:", "illuminaHumanv2.db", sep=""), search())
# kegg.ids <- ls(illuminaHumanv2PATH2PROBE) 
# gene.ids <- ls(illuminaHumanv2PATH)
# database <-"KEGG"
# analysis <- "microarray"
# imat <- buildKeggIncidence(kegg.ids, gene.ids, illuminaHumanv2.db,database, analysis, envPos) 
# ## End(Not run)

Run the code above in your browser using DataLab