Learn R Programming

attract (version 1.24.0)

calcFuncSynexprs: Functional enrichmental analysis for a set of synexpression groups.

Description

This function performs functional enrichment for a given set of synexpression groups.

Usage

calcFuncSynexprs(mySynExpressionSet, myAttractorModuleSet, ontology = "BP", min.pvalue = 0.05, min.pwaysize = 5, annotation = "illuminaHumanv2.db", analysis="microarray", ...)

Arguments

mySynExpressionSet
SynExpressionSet object.
myAttractorModuleSet
AttractorModuleSet object.
ontology
character string specifying which GO ontology to use, either "MF", "BP", or "CC"; defaults to "BP".
min.pvalue
numeric value specifying adjusted P-value cut-off to use, categories with P-values
min.pwaysize
integer specifying minimum size of the pathway or category to consider for enrichment analysis.
annotation
character string specifying the annotation package that corresponds to the chip platform the data was generated from.
analysis
a character string specifying what type of experiment you performed, microarray or RNAseq.
...
additional arguments.

Value

A list object.

Details

This function performs a functional enrichment analysis on each synexpression group using the hyperGTest from the GOstats package. P-values are adjusted using the Benjamini-Hochberg correction method. Results are returned only if they satisfy the minimum P-value level, as specified by the min.pvalue argument.

References

Falcon, S. and R. Gentleman, Using GOstats to test gene lists for GO term association. Bioinformatics, 2007. 23(2): p. 257-8.

Examples

Run this code
data(subset.loring.eset)
attractor.states <- findAttractors(subset.loring.eset, "celltype", nperm=10, annotation="illuminaHumanv1.db",analysis="microarray")
remove.these.genes <- removeFlatGenes(subset.loring.eset, "celltype", contrasts=NULL, limma.cutoff=0.05)
mapk.syn <- findSynexprs("04010", attractor.states, remove.these.genes)
mapk.func <- calcFuncSynexprs(mapk.syn, attractor.states, "CC", annotation="illuminaHumanv1.db") 

Run the code above in your browser using DataLab