findAttractors(myEset, cellTypeTag, min.pwaysize = 5, annotation = "illuminaHumanv2.db", database="KEGG", analysis="microarray", databaseGeneFormat=NULL, ...)ExpressionSet object.
pData(myEset)).
integer specifying the minimum size of the KEGG or reactome pathways to consider in the analysis.
AttractorModuleSet object.
rankedPathways.
The output object of the findAttractors function also contains the incidence matrix that was built for the KEGG or reactome pathways, stored in
the slot incidenceMatrix and the character string denoting which column of the sample data represents the cell type or
experimental groups of interest, as stored in the slot cellTypeTag.
data(subset.loring.eset)
attractor.states <- findAttractors(subset.loring.eset, "celltype", annotation="illuminaHumanv1.db",database="KEGG", analysis="microarray",)
Run the code above in your browser using DataLab