Learn R Programming

attract (version 1.24.0)

findOnepwaySynexprs: Internal function - finds the synexpression groups for a single given pathway.

Description

Internal function - finds the synexpression groups for a single given pathway.

Usage

findOnepwaySynexprs(myIDs, myDataSet, cellTypeTag, min.clustersize = 5, removeGenes = NULL, ...)

Arguments

myIDs
a single character string denoting the KEGG or reactome ID of the pathway module to be analyzed or a character codevector of gene names of a pathway.
myDataSet
AttractorModuleSet object, output of the findAttractors step. This could also be an ExpressionSet object.
cellTypeTag
character string of the variable name which stores the cell-lineages or experimental groups of interest for the samples in the data set (this string should be one of the column names of pData(myEset)).
min.clustersize
integer specifying the minimum number of genes that must be present in clusters that are inferred.
removeGenes
vector of probes that specify those genes who demonstrate little variability across the different celltypes and thus should be removed from downstream analysis.
...
additional arguments.

Value

A SynExpressionSet object is returned.

Details

This function is called internally by calcFuncSynexprs. Users should use calcFuncSynexprs rather than calling findOnepwaySynexprs directly.

Examples

Run this code
## Not run: 
# data(subset.loring.eset)
# attractor.states <- findAttractors(subset.loring.eset, "celltype", nperm=10, annotation="illuminaHumanv1.db")
# remove.these.genes <- removeFlatGenes(subset.loring.eset, "celltype", contrasts=NULL, limma.cutoff=0.05)
# map.syn <- findOnepwaySynexprs("04010", attractor.states, "celltype", removeGenes=remove.these.genes)
# vec.geneid <- c("GI_17999531-S","GI_17978503-A")
# custom.syn <- findSynexprs(vec.geneid, subset.loring.eset, "celltype", removeGenes=remove.these.genes)
# ## End(Not run)

Run the code above in your browser using DataLab