Learn R Programming

attract (version 1.24.0)

getPwayGenes: Function removes genes from the chosen pathway that demonstrate little variation across the cell types.

Description

Function removes genes from the chosen pathway that demonstrate little variation across the cell types.

Usage

getPwayGenes(pathwayIds, myAttractorModuleSet, removeGenes = NULL)

Arguments

pathwayIds
a single character string denoting the KEGG or reactome ID of the pathway module to be analyzed.
myAttractorModuleSet
AttractorModuleSet object, output of the findAttractors step.
removeGenes
vector of probes or gene IDs (RNAseq) that specify those genes who demonstrate little variability across the different celltypes and thus should be removed from downstream analysis.

Value

A vector of gene names that have variable expression across the different cell types in a pathway.

Details

This function is also called internally by findSynexprs.

References

Mar, J., C. Wells, and J. Quackenbush, Defining an Informativeness Metric for Clustering Gene Expression Data. to appear, 2010.

Examples

Run this code
## Not run: 
# data(subset.loring.eset)
# attractor.states <- findAttractors(subset.loring.eset, "celltype", nperm=10, annotation="illuminaHumanv1.db")
# remove.these.genes <- removeFlatGenes(subset.loring.eset, "celltype", contrasts=NULL, limma.cutoff=0.05)
# map.syn <- getPwayGenes("04010", attractor.states, removeGenes=remove.these.genes)## End(Not run)

Run the code above in your browser using DataLab