## Not run:
# library(cluster)
# data(subset.loring.eset)
# clustObj <- agnes(as.dist(1-t(cor(exprs(subset.loring.eset)))))
# crss.vals <- NULL
# for( i in 1:10 ){
# crss.vals <- c(crss.vals, calcRss(exprs(subset.loring.eset), cutree(clustObj,i), pData(subset.loring.eset)$celltype))
# }
# # The RSS values are expected to be smaller than the informativeness metric values in the presence of genuine cluster structure.
# ## End(Not run)
Run the code above in your browser using DataLab